# imWatermark
This snippet of code attempts to watermark images.

# Output
This is a sample image:  
!["Sample Image"](https://raw.githubusercontent.com/Mamdasn/imWatermark/main/assets/lotus.jpg "Sample Image")  
This is the sample image watermarked:  
![Watermarked Sample Image](https://raw.githubusercontent.com/Mamdasn/imWatermark/main/assets/lotus-watermark.jpg "Watermarked Sample Image")
